import { useState, useCallback, useEffect } from 'react';

const createStoreHook = store => key => {
  const [value, setValue] = useState(store.get(key));
  const setValueWrapper = useCallback(value => setValue(value), [setValue]);
  const setter = useCallback(newValue => store.set(key, newValue), [key]);
  useEffect(() => {
    const subscription = store.subscribe(key, setValueWrapper, {
      withInitialValue: true
    });
    return () => subscription.unsubscribe();
  }, [setValueWrapper]);
  return [value, setter];
};

export { createStoreHook };
