'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');

const createStoreHook = store => key => {
  const [value, setValue] = react.useState(store.get(key));
  const setValueWrapper = react.useCallback(value => setValue(value), [setValue]);
  const setter = react.useCallback(newValue => store.set(key, newValue), [key]);
  react.useEffect(() => {
    const subscription = store.subscribe(key, setValueWrapper, {
      withInitialValue: true
    });
    return () => subscription.unsubscribe();
  }, [setValueWrapper]);
  return [value, setter];
};

exports.createStoreHook = createStoreHook;
